summaryrefslogtreecommitdiffstats
path: root/kdevdesigner/designer/command.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kdevdesigner/designer/command.cpp')
-rw-r--r--kdevdesigner/designer/command.cpp38
1 files changed, 19 insertions, 19 deletions
diff --git a/kdevdesigner/designer/command.cpp b/kdevdesigner/designer/command.cpp
index f66ab073..95f9e68a 100644
--- a/kdevdesigner/designer/command.cpp
+++ b/kdevdesigner/designer/command.cpp
@@ -261,19 +261,19 @@ void ResizeCommand::unexecute()
InsertCommand::InsertCommand( const TQString &n, FormWindow *fw,
TQWidget *w, const TQRect &g )
- : Command( n, fw ), widget( w ), tqgeometry( g )
+ : Command( n, fw ), widget( w ), geometry( g )
{
}
void InsertCommand::execute()
{
- if ( tqgeometry.size() == TQSize( 0, 0 ) ) {
- widget->move( tqgeometry.topLeft() );
+ if ( geometry.size() == TQSize( 0, 0 ) ) {
+ widget->move( geometry.topLeft() );
widget->adjustSize();
} else {
- TQSize s = tqgeometry.size().expandedTo( widget->minimumSize() );
+ TQSize s = geometry.size().expandedTo( widget->minimumSize() );
s = s.expandedTo( widget->minimumSizeHint() );
- TQRect r( tqgeometry.topLeft(), s );
+ TQRect r( geometry.topLeft(), s );
widget->setGeometry( r );
}
widget->show();
@@ -369,17 +369,17 @@ DeleteCommand::DeleteCommand( const TQString &n, FormWindow *fw,
TQWidgetList copyOfWidgets = widgets;
copyOfWidgets.setAutoDelete(FALSE);
// Include the tqchildren of the selected items when deleting
for ( TQWidget *w = widgets.first(); w; w = widgets.next() ) {
- TQObjectList *tqchildren = w->queryList( TQWIDGET_OBJECT_NAME_STRING );
- for ( TQWidget *c = (TQWidget *)tqchildren->first(); c; c = (TQWidget *)tqchildren->next() ) {
+ TQObjectList *children = w->queryList( TQWIDGET_OBJECT_NAME_STRING );
+ for ( TQWidget *c = (TQWidget *)children->first(); c; c = (TQWidget *)children->next() ) {
if ( copyOfWidgets.find( c ) == -1 && formWindow()->widgets()->find( c ) ) {
widgets.insert(widgets.at() + 1, c);
widgets.prev();
copyOfWidgets.append(c);
}
}
- delete tqchildren;
+ delete children;
}
}
@@ -566,23 +566,23 @@ void SetPropertyCommand::setProperty( const TQVariant &v, const TQString &curren
widget->metaObject()->property( widget->metaObject()->findProperty( propName, TRUE ), TRUE );
if ( !p ) {
if ( propName == "hAlign" ) {
- p = widget->metaObject()->property( widget->metaObject()->findProperty( "tqalignment", TRUE ), TRUE );
- int align = widget->property( "tqalignment" ).toInt();
+ p = widget->metaObject()->property( widget->metaObject()->findProperty( "alignment", TRUE ), TRUE );
+ int align = widget->property( "alignment" ).toInt();
align &= ~( AlignHorizontal_Mask );
align |= p->keyToValue( currentItemText );
- widget->setProperty( "tqalignment", TQVariant( align ) );
+ widget->setProperty( "alignment", TQVariant( align ) );
} else if ( propName == "vAlign" ) {
- p = widget->metaObject()->property( widget->metaObject()->findProperty( "tqalignment", TRUE ), TRUE );
- int align = widget->property( "tqalignment" ).toInt();
+ p = widget->metaObject()->property( widget->metaObject()->findProperty( "alignment", TRUE ), TRUE );
+ int align = widget->property( "alignment" ).toInt();
align &= ~( AlignVertical_Mask );
align |= p->keyToValue( currentItemText );
- widget->setProperty( "tqalignment", TQVariant( align ) );
+ widget->setProperty( "alignment", TQVariant( align ) );
} else if ( propName == "wordwrap" ) {
- int align = widget->property( "tqalignment" ).toInt();
+ int align = widget->property( "alignment" ).toInt();
align &= ~WordBreak;
if ( v.toBool() )
align |= WordBreak;
- widget->setProperty( "tqalignment", TQVariant( align ) );
+ widget->setProperty( "alignment", TQVariant( align ) );
} else if ( propName == "layoutSpacing" ) {
TQVariant val = v;
if ( val.toString() == "default" )
@@ -2390,8 +2390,8 @@ TQString RenameMenuCommand::makeLegal( const TQString &str )
// remove illegal characters
TQString d;
char c = 0, i = 0;
- while ( !str.tqat(i).isNull() ) {
- c = str.tqat(i).latin1();
+ while ( !str.at(i).isNull() ) {
+ c = str.at(i).latin1();
if ( c == '-' || c == ' ' )
d += '_';
else if ( ( c >= '0' && c <= '9') || ( c >= 'A' && c <= 'Z' )
@@ -369,17 +369,17 @@ DeleteCommand::DeleteCommand( const TQString &n, FormWindow *fw,
TQWidgetList copyOfWidgets = widgets;
copyOfWidgets.setAutoDelete(FALSE);
- // Include the tqchildren of the selected items when deleting
+ // Include the children of the selected items when deleting
for ( TQWidget *w = widgets.first(); w; w = widgets.next() ) {